import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { LogEntryListModel } from '../model/logEntryListModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace logsAuditLogsGet {
    interface Params {
        /**
        * The start of the time interval<br />A date and time (without fractional second part) in UTC or with UTC offset as defined in <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>
        */
        from?: Date;
        /**
        * The end of the time interval, must be larger than 'from'<br />A date and time (without fractional second part) in UTC or with UTC offset as defined in <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>
        */
        to?: Date;
        /**
        * The types of entities being tracked as a group.  Example: If a unit maintenance is created, the AggregateType would be Unit.
        */
        aggregateTypes?: Array<string>;
        /**
        * A unique identifiers for the groups of related changes.  Example: If a unit maintenance is created, the AggregateId would be the unique ID of that unit.
        */
        aggregateIds?: Array<string>;
        /**
        * The types of the specific objects that were changed.  Example: If a unit maintenance is created, the EntityType would be Maintenance.
        */
        entityTypes?: Array<string>;
        /**
        * A unique identifiers for the specific objects that were changed.  Example: If a unit maintenance is created, the EntityId would be the unique ID of that maintenance.
        */
        entityIds?: Array<string>;
        /**
        * Filter result by requested properties
        */
        propertyIds?: Array<string>;
        /**
        * Filter result by requested clients
        */
        clientIds?: Array<string>;
        /**
        * Filter result by requested subjects
        */
        subjectIds?: Array<string>;
        /**
        * Filter result by requested actions
        */
        actions?: Array<ActionsEnum>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Cursor to get next data page. Results in 204 if there are no items on that page.
        */
        cursor?: string;
        /**
        * Page size. Default value is 50. Maximal value is 500
        */
        pageSize?: number;
    }
    type ActionsEnum = 'Created' | 'Updated' | 'Deleted';
    const ActionsEnumValues: readonly ActionsEnum[];
}
export declare class AuditLogsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Returns a list of audit log entries.
     * &lt;br&gt;You must have this scope: &#39;logs.read&#39;.
     * @param $params.from The start of the time interval&lt;br /&gt;A date and time (without fractional second part) in UTC or with UTC offset as defined in &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;
     * @param $params.to The end of the time interval, must be larger than &#39;from&#39;&lt;br /&gt;A date and time (without fractional second part) in UTC or with UTC offset as defined in &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;
     * @param $params.aggregateTypes The types of entities being tracked as a group.  Example: If a unit maintenance is created, the AggregateType would be Unit.
     * @param $params.aggregateIds A unique identifiers for the groups of related changes.  Example: If a unit maintenance is created, the AggregateId would be the unique ID of that unit.
     * @param $params.entityTypes The types of the specific objects that were changed.  Example: If a unit maintenance is created, the EntityType would be Maintenance.
     * @param $params.entityIds A unique identifiers for the specific objects that were changed.  Example: If a unit maintenance is created, the EntityId would be the unique ID of that maintenance.
     * @param $params.propertyIds Filter result by requested properties
     * @param $params.clientIds Filter result by requested clients
     * @param $params.subjectIds Filter result by requested subjects
     * @param $params.actions Filter result by requested actions
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.cursor Cursor to get next data page. Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. Default value is 50. Maximal value is 500
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    logsAuditLogsGet($params: logsAuditLogsGet.Params, observe?: 'body', reportProgress?: boolean): Observable<LogEntryListModel | null>;
    logsAuditLogsGet($params: logsAuditLogsGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<LogEntryListModel | null>>;
    logsAuditLogsGet($params: logsAuditLogsGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<LogEntryListModel | null>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AuditLogsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AuditLogsService>;
}
