import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ReservationChangeLogListModel } from '../model/reservationChangeLogListModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace logsBookingReservationGet {
    interface Params {
        /**
        * Filter the log entries by reservation IDs
        */
        reservationIds?: Array<string>;
        /**
        * Filter the log entries by event types.
        */
        eventTypes?: Array<EventTypesEnum>;
        /**
        * Filter the log entries by client IDs (which application triggered this event)
        */
        clientIds?: Array<string>;
        /**
        * Filter the log entries by property IDs
        */
        propertyIds?: Array<string>;
        /**
        * Filter the log entries by subject IDs (which user triggered this event)
        */
        subjectIds?: Array<string>;
        /**
        * Filter by event date and time<br />You can provide an array of string expressions which all need to apply.<br />Each expression has the form of 'OPERATION_VALUE' where VALUE needs to be of the valid format of the property type and OPERATION can be:<br />'eq' for equals<br />'neq' for not equals<br />'lt' for less than<br />'gt' for greater than<br />'lte' for less than or equals<br />'gte' for greater than or equals<br />For instance<br />'eq_5' would mean the value should equal 5<br />'lte_7' would mean the value should be less than or equal to 7
        */
        dateFilter?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
        /**
        * List of all embedded resources that should be expanded in the response. Possible values are: changes. All other values will be silently ignored.
        */
        expand?: Array<ExpandEnum>;
    }
    type EventTypesEnum = 'Created' | 'Amended' | 'CheckedIn' | 'CheckedOut' | 'Canceled' | 'SetToNoShow' | 'CityTaxAdded' | 'CityTaxRemoved' | 'UnitAssigned' | 'UnitUnassigned' | 'PaymentAccountSet' | 'PaymentAccountRemoved' | 'InvoiceStatusChanged' | 'Changed' | 'CheckInReverted' | 'UnitLocked' | 'UnitUnlocked';
    const EventTypesEnumValues: readonly EventTypesEnum[];
    type ExpandEnum = 'changes';
    const ExpandEnumValues: readonly "changes"[];
}
export declare class BookingLogsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Returns reservation change log entries sorted by the timestamp.
     * &lt;br&gt;You must have this scope: &#39;logs.read&#39;.
     * @param $params.reservationIds Filter the log entries by reservation IDs
     * @param $params.eventTypes Filter the log entries by event types.
     * @param $params.clientIds Filter the log entries by client IDs (which application triggered this event)
     * @param $params.propertyIds Filter the log entries by property IDs
     * @param $params.subjectIds Filter the log entries by subject IDs (which user triggered this event)
     * @param $params.dateFilter Filter by event date and time&lt;br /&gt;You can provide an array of string expressions which all need to apply.&lt;br /&gt;Each expression has the form of &#39;OPERATION_VALUE&#39; where VALUE needs to be of the valid format of the property type and OPERATION can be:&lt;br /&gt;&#39;eq&#39; for equals&lt;br /&gt;&#39;neq&#39; for not equals&lt;br /&gt;&#39;lt&#39; for less than&lt;br /&gt;&#39;gt&#39; for greater than&lt;br /&gt;&#39;lte&#39; for less than or equals&lt;br /&gt;&#39;gte&#39; for greater than or equals&lt;br /&gt;For instance&lt;br /&gt;&#39;eq_5&#39; would mean the value should equal 5&lt;br /&gt;&#39;lte_7&#39; would mean the value should be less than or equal to 7
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param $params.expand List of all embedded resources that should be expanded in the response. Possible values are: changes. All other values will be silently ignored.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    logsBookingReservationGet($params: logsBookingReservationGet.Params, observe?: 'body', reportProgress?: boolean): Observable<ReservationChangeLogListModel | null>;
    logsBookingReservationGet($params: logsBookingReservationGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ReservationChangeLogListModel | null>>;
    logsBookingReservationGet($params: logsBookingReservationGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ReservationChangeLogListModel | null>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BookingLogsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BookingLogsService>;
}
