import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AccountingConfigUpdateListModel } from '../model/accountingConfigUpdateListModel';
import { FolioChangeLogListModel } from '../model/folioChangeLogListModel';
import { NightAuditLogListModel } from '../model/nightAuditLogListModel';
import { TransactionsExportLogListModel } from '../model/transactionsExportLogListModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace logsFinanceAccountingConfigUpdatesGet {
    interface Params {
        /**
        * Filter the log entries by status.
        */
        statuses?: Array<StatusesEnum>;
        /**
        * Filter the log entries by property IDs
        */
        propertyIds?: Array<string>;
        /**
        * Filter the log entries by subject IDs (which user triggered this event)
        */
        subjectIds?: Array<string>;
        /**
        * Filter by event date and time<br />You can provide an array of string expressions which all need to apply.<br />Each expression has the form of 'OPERATION_VALUE' where VALUE needs to be of the valid format of the property type and OPERATION can be:<br />'eq' for equals<br />'neq' for not equals<br />'lt' for less than<br />'gt' for greater than<br />'lte' for less than or equals<br />'gte' for greater than or equals<br />For instance<br />'eq_5' would mean the value should equal 5<br />'lte_7' would mean the value should be less than or equal to 7
        */
        dateFilter?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
    }
    type StatusesEnum = 'InProgress' | 'Success' | 'Failure';
    const StatusesEnumValues: readonly StatusesEnum[];
}
export declare namespace logsFinanceFolioGet {
    interface Params {
        /**
        * Filter the log entries by folio IDs
        */
        folioIds?: Array<string>;
        /**
        * Filter the log entries by event types.
        */
        eventTypes?: Array<EventTypesEnum>;
        /**
        * Filter the log entries by client IDs (which application triggered this event)
        */
        clientIds?: Array<string>;
        /**
        * Filter the log entries by property IDs
        */
        propertyIds?: Array<string>;
        /**
        * Filter the log entries by subject IDs (which user triggered this event)
        */
        subjectIds?: Array<string>;
        /**
        * Filter by event date and time<br />You can provide an array of string expressions which all need to apply.<br />Each expression has the form of 'OPERATION_VALUE' where VALUE needs to be of the valid format of the property type and OPERATION can be:<br />'eq' for equals<br />'neq' for not equals<br />'lt' for less than<br />'gt' for greater than<br />'lte' for less than or equals<br />'gte' for greater than or equals<br />For instance<br />'eq_5' would mean the value should equal 5<br />'lte_7' would mean the value should be less than or equal to 7
        */
        dateFilter?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
    }
    type EventTypesEnum = 'Created' | 'ChargePosted' | 'TransitoryChargePosted' | 'AllowancePosted' | 'PaymentPosted' | 'ChargeMovedFromFolio' | 'TransitoryChargeMovedFromFolio' | 'PaymentMovedFromFolio' | 'ChargeMovedToFolio' | 'TransitoryChargeMovedToFolio' | 'PaymentMovedToFolio' | 'Closed' | 'Reopened' | 'Deleted' | 'DebitorChanged' | 'AllowanceMovedFromFolio' | 'AllowanceMovedToFolio' | 'RefundPosted' | 'RefundMovedFromFolio' | 'RefundMovedToFolio' | 'InvoiceCreated' | 'InvoiceCanceled' | 'InvoicePaid' | 'ChargesChanged' | 'PaymentAdded' | 'PaymentFailed' | 'PaymentCanceled' | 'RefundAdded' | 'RefundFailed' | 'InvoiceWrittenOff' | 'DepositItemAdded' | 'DepositItemChanged' | 'DepositItemDeleted';
    const EventTypesEnumValues: readonly EventTypesEnum[];
}
export declare namespace logsFinanceNightAuditGet {
    interface Params {
        /**
        * Filter the log entries by status.
        */
        statuses?: Array<StatusesEnum>;
        /**
        * Filter the log entries by property IDs
        */
        propertyIds?: Array<string>;
        /**
        * Filter the log entries by subject IDs (which user triggered this event)
        */
        subjectIds?: Array<string>;
        /**
        * Filter by event date and time<br />You can provide an array of string expressions which all need to apply.<br />Each expression has the form of 'OPERATION_VALUE' where VALUE needs to be of the valid format of the property type and OPERATION can be:<br />'eq' for equals<br />'neq' for not equals<br />'lt' for less than<br />'gt' for greater than<br />'lte' for less than or equals<br />'gte' for greater than or equals<br />For instance<br />'eq_5' would mean the value should equal 5<br />'lte_7' would mean the value should be less than or equal to 7
        */
        dateFilter?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
    }
    type StatusesEnum = 'InProgress' | 'Success' | 'Failure';
    const StatusesEnumValues: readonly StatusesEnum[];
}
export declare namespace logsFinanceTransactionsExportGet {
    interface Params {
        /**
        * Filter the log entries by export log types.
        */
        types?: Array<TypesEnum>;
        /**
        * Filter the log entries by property IDs
        */
        propertyIds?: Array<string>;
        /**
        * Filter the log entries by subject IDs (which user triggered this event)
        */
        subjectIds?: Array<string>;
        /**
        * Filter by event date and time<br />You can provide an array of string expressions which all need to apply.<br />Each expression has the form of 'OPERATION_VALUE' where VALUE needs to be of the valid format of the property type and OPERATION can be:<br />'eq' for equals<br />'neq' for not equals<br />'lt' for less than<br />'gt' for greater than<br />'lte' for less than or equals<br />'gte' for greater than or equals<br />For instance<br />'eq_5' would mean the value should equal 5<br />'lte_7' would mean the value should be less than or equal to 7
        */
        dateFilter?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
    }
    type TypesEnum = 'Raw' | 'Aggregate' | 'AggregatePairs';
    const TypesEnumValues: readonly TypesEnum[];
}
export declare class FinanceLogsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Returns the accounting config updates logs.
     * Returns a log of all accounting config updates  Newest log entries are returned first.&lt;br&gt;You must have this scope: &#39;logs.read&#39;.
     * @param $params.statuses Filter the log entries by status.
     * @param $params.propertyIds Filter the log entries by property IDs
     * @param $params.subjectIds Filter the log entries by subject IDs (which user triggered this event)
     * @param $params.dateFilter Filter by event date and time&lt;br /&gt;You can provide an array of string expressions which all need to apply.&lt;br /&gt;Each expression has the form of &#39;OPERATION_VALUE&#39; where VALUE needs to be of the valid format of the property type and OPERATION can be:&lt;br /&gt;&#39;eq&#39; for equals&lt;br /&gt;&#39;neq&#39; for not equals&lt;br /&gt;&#39;lt&#39; for less than&lt;br /&gt;&#39;gt&#39; for greater than&lt;br /&gt;&#39;lte&#39; for less than or equals&lt;br /&gt;&#39;gte&#39; for greater than or equals&lt;br /&gt;For instance&lt;br /&gt;&#39;eq_5&#39; would mean the value should equal 5&lt;br /&gt;&#39;lte_7&#39; would mean the value should be less than or equal to 7
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    logsFinanceAccountingConfigUpdatesGet($params: logsFinanceAccountingConfigUpdatesGet.Params, observe?: 'body', reportProgress?: boolean): Observable<AccountingConfigUpdateListModel | null>;
    logsFinanceAccountingConfigUpdatesGet($params: logsFinanceAccountingConfigUpdatesGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<AccountingConfigUpdateListModel | null>>;
    logsFinanceAccountingConfigUpdatesGet($params: logsFinanceAccountingConfigUpdatesGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<AccountingConfigUpdateListModel | null>>;
    /**
     * Returns folio change log entries sorted by the timestamp.
     * &lt;br&gt;You must have this scope: &#39;logs.read&#39;.
     * @param $params.folioIds Filter the log entries by folio IDs
     * @param $params.eventTypes Filter the log entries by event types.
     * @param $params.clientIds Filter the log entries by client IDs (which application triggered this event)
     * @param $params.propertyIds Filter the log entries by property IDs
     * @param $params.subjectIds Filter the log entries by subject IDs (which user triggered this event)
     * @param $params.dateFilter Filter by event date and time&lt;br /&gt;You can provide an array of string expressions which all need to apply.&lt;br /&gt;Each expression has the form of &#39;OPERATION_VALUE&#39; where VALUE needs to be of the valid format of the property type and OPERATION can be:&lt;br /&gt;&#39;eq&#39; for equals&lt;br /&gt;&#39;neq&#39; for not equals&lt;br /&gt;&#39;lt&#39; for less than&lt;br /&gt;&#39;gt&#39; for greater than&lt;br /&gt;&#39;lte&#39; for less than or equals&lt;br /&gt;&#39;gte&#39; for greater than or equals&lt;br /&gt;For instance&lt;br /&gt;&#39;eq_5&#39; would mean the value should equal 5&lt;br /&gt;&#39;lte_7&#39; would mean the value should be less than or equal to 7
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    logsFinanceFolioGet($params: logsFinanceFolioGet.Params, observe?: 'body', reportProgress?: boolean): Observable<FolioChangeLogListModel | null>;
    logsFinanceFolioGet($params: logsFinanceFolioGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<FolioChangeLogListModel | null>>;
    logsFinanceFolioGet($params: logsFinanceFolioGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<FolioChangeLogListModel | null>>;
    /**
     * Returns the night audit logs.
     * Returns a log of all night audits  Newest log entries are returned first.&lt;br&gt;You must have this scope: &#39;logs.read&#39;.
     * @param $params.statuses Filter the log entries by status.
     * @param $params.propertyIds Filter the log entries by property IDs
     * @param $params.subjectIds Filter the log entries by subject IDs (which user triggered this event)
     * @param $params.dateFilter Filter by event date and time&lt;br /&gt;You can provide an array of string expressions which all need to apply.&lt;br /&gt;Each expression has the form of &#39;OPERATION_VALUE&#39; where VALUE needs to be of the valid format of the property type and OPERATION can be:&lt;br /&gt;&#39;eq&#39; for equals&lt;br /&gt;&#39;neq&#39; for not equals&lt;br /&gt;&#39;lt&#39; for less than&lt;br /&gt;&#39;gt&#39; for greater than&lt;br /&gt;&#39;lte&#39; for less than or equals&lt;br /&gt;&#39;gte&#39; for greater than or equals&lt;br /&gt;For instance&lt;br /&gt;&#39;eq_5&#39; would mean the value should equal 5&lt;br /&gt;&#39;lte_7&#39; would mean the value should be less than or equal to 7
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    logsFinanceNightAuditGet($params: logsFinanceNightAuditGet.Params, observe?: 'body', reportProgress?: boolean): Observable<NightAuditLogListModel | null>;
    logsFinanceNightAuditGet($params: logsFinanceNightAuditGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<NightAuditLogListModel | null>>;
    logsFinanceNightAuditGet($params: logsFinanceNightAuditGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<NightAuditLogListModel | null>>;
    /**
     * Returns the audit log for all accounting exports that have been done.
     * Returns the audit log for all exports if accounting data that have been done.&lt;br&gt;You must have this scope: &#39;logs.read&#39;.
     * @param $params.types Filter the log entries by export log types.
     * @param $params.propertyIds Filter the log entries by property IDs
     * @param $params.subjectIds Filter the log entries by subject IDs (which user triggered this event)
     * @param $params.dateFilter Filter by event date and time&lt;br /&gt;You can provide an array of string expressions which all need to apply.&lt;br /&gt;Each expression has the form of &#39;OPERATION_VALUE&#39; where VALUE needs to be of the valid format of the property type and OPERATION can be:&lt;br /&gt;&#39;eq&#39; for equals&lt;br /&gt;&#39;neq&#39; for not equals&lt;br /&gt;&#39;lt&#39; for less than&lt;br /&gt;&#39;gt&#39; for greater than&lt;br /&gt;&#39;lte&#39; for less than or equals&lt;br /&gt;&#39;gte&#39; for greater than or equals&lt;br /&gt;For instance&lt;br /&gt;&#39;eq_5&#39; would mean the value should equal 5&lt;br /&gt;&#39;lte_7&#39; would mean the value should be less than or equal to 7
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    logsFinanceTransactionsExportGet($params: logsFinanceTransactionsExportGet.Params, observe?: 'body', reportProgress?: boolean): Observable<TransactionsExportLogListModel | null>;
    logsFinanceTransactionsExportGet($params: logsFinanceTransactionsExportGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TransactionsExportLogListModel | null>>;
    logsFinanceTransactionsExportGet($params: logsFinanceTransactionsExportGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TransactionsExportLogListModel | null>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<FinanceLogsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FinanceLogsService>;
}
