import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Optional, Inject, NgModule, SkipSelf } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpUrlEncodingCodec, HttpParams, HttpHeaders } from '@angular/common/http';
import { dateToApaleoIso } from '@apaleo/angular-api-proxy-common';

/**
* CustomHttpUrlEncodingCodec
* Fix plus sign (+) not encoding, so sent as blank space
* See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
*/
class CustomHttpUrlEncodingCodec extends HttpUrlEncodingCodec {
    encodeKey(k) {
        k = super.encodeKey(k);
        return k.replace(/\+/gi, '%2B');
    }
    encodeValue(v) {
        v = super.encodeValue(v);
        return v.replace(/\+/gi, '%2B');
    }
}

const BASE_PATH = new InjectionToken('basePath');
const COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

class Configuration {
    constructor(configurationParameters = {}) {
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    /**
     * Select the correct content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param contentTypes - the array of content types that are available for selection
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderContentType(contentTypes) {
        if (contentTypes.length == 0) {
            return undefined;
        }
        let type = contentTypes.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    }
    /**
     * Select the correct accept content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct accept content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param accepts - the array of content types that are available for selection.
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderAccept(accepts) {
        if (accepts.length == 0) {
            return undefined;
        }
        let type = accepts.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    }
    /**
     * Check if the given MIME is a JSON MIME.
     * JSON MIME examples:
     *   application/json
     *   application/json; charset=UTF8
     *   APPLICATION/JSON
     *   application/vnd.company+json
     * @param mime - MIME (Multipurpose Internet Mail Extensions)
     * @return True if the given MIME is JSON, false otherwise.
     */
    isJsonMime(mime) {
        const jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    }
}

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$2(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
var logsAuditLogsGet;
(function (logsAuditLogsGet) {
    logsAuditLogsGet.ActionsEnumValues = Object.freeze(['Created', 'Updated', 'Deleted']);
})(logsAuditLogsGet || (logsAuditLogsGet = {}));
class AuditLogsService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    logsAuditLogsGet($params, observe = 'body', reportProgress = false) {
        const from = $params.from;
        const to = $params.to;
        const aggregateTypes = $params.aggregateTypes;
        const aggregateIds = $params.aggregateIds;
        const entityTypes = $params.entityTypes;
        const entityIds = $params.entityIds;
        const propertyIds = $params.propertyIds;
        const clientIds = $params.clientIds;
        const subjectIds = $params.subjectIds;
        const actions = $params.actions;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const cursor = $params.cursor;
        const pageSize = $params.pageSize;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (from !== undefined && from !== null) {
            queryParameters = queryParameters.set('from', dateToApaleoIso(from));
        }
        if (to !== undefined && to !== null) {
            queryParameters = queryParameters.set('to', dateToApaleoIso(to));
        }
        if (aggregateTypes) {
            queryParameters = queryParameters.set('aggregateTypes', aggregateTypes.join(COLLECTION_FORMATS['csv']));
        }
        if (aggregateIds) {
            queryParameters = queryParameters.set('aggregateIds', aggregateIds.join(COLLECTION_FORMATS['csv']));
        }
        if (entityTypes) {
            queryParameters = queryParameters.set('entityTypes', entityTypes.join(COLLECTION_FORMATS['csv']));
        }
        if (entityIds) {
            queryParameters = queryParameters.set('entityIds', entityIds.join(COLLECTION_FORMATS['csv']));
        }
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        if (clientIds) {
            queryParameters = queryParameters.set('clientIds', clientIds.join(COLLECTION_FORMATS['csv']));
        }
        if (subjectIds) {
            queryParameters = queryParameters.set('subjectIds', subjectIds.join(COLLECTION_FORMATS['csv']));
        }
        if (actions) {
            queryParameters = queryParameters.set('actions', actions.join(COLLECTION_FORMATS['csv']));
        }
        if (cursor !== undefined && cursor !== null) {
            queryParameters = queryParameters.set('cursor', cursor);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/logs/v0-nsfw/audit-logs`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function AuditLogsService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || AuditLogsService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: AuditLogsService, factory: AuditLogsService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(AuditLogsService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$1(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
var logsBookingReservationGet;
(function (logsBookingReservationGet) {
    logsBookingReservationGet.EventTypesEnumValues = Object.freeze(['Created', 'Amended', 'CheckedIn', 'CheckedOut', 'Canceled', 'SetToNoShow', 'CityTaxAdded', 'CityTaxRemoved', 'UnitAssigned', 'UnitUnassigned', 'PaymentAccountSet', 'PaymentAccountRemoved', 'InvoiceStatusChanged', 'Changed', 'CheckInReverted', 'UnitLocked', 'UnitUnlocked']);
    logsBookingReservationGet.ExpandEnumValues = Object.freeze(['changes']);
})(logsBookingReservationGet || (logsBookingReservationGet = {}));
class BookingLogsService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    logsBookingReservationGet($params, observe = 'body', reportProgress = false) {
        const reservationIds = $params.reservationIds;
        const eventTypes = $params.eventTypes;
        const clientIds = $params.clientIds;
        const propertyIds = $params.propertyIds;
        const subjectIds = $params.subjectIds;
        const dateFilter = $params.dateFilter;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        const expand = $params.expand;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (reservationIds) {
            queryParameters = queryParameters.set('reservationIds', reservationIds.join(COLLECTION_FORMATS['csv']));
        }
        if (eventTypes) {
            queryParameters = queryParameters.set('eventTypes', eventTypes.join(COLLECTION_FORMATS['csv']));
        }
        if (clientIds) {
            queryParameters = queryParameters.set('clientIds', clientIds.join(COLLECTION_FORMATS['csv']));
        }
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        if (subjectIds) {
            queryParameters = queryParameters.set('subjectIds', subjectIds.join(COLLECTION_FORMATS['csv']));
        }
        if (dateFilter) {
            queryParameters = queryParameters.set('dateFilter', dateFilter.join(COLLECTION_FORMATS['csv']));
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        if (expand) {
            queryParameters = queryParameters.set('expand', expand.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/logs/v0-nsfw/booking/reservation`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function BookingLogsService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || BookingLogsService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: BookingLogsService, factory: BookingLogsService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(BookingLogsService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
var logsFinanceAccountingConfigUpdatesGet;
(function (logsFinanceAccountingConfigUpdatesGet) {
    logsFinanceAccountingConfigUpdatesGet.StatusesEnumValues = Object.freeze(['InProgress', 'Success', 'Failure']);
})(logsFinanceAccountingConfigUpdatesGet || (logsFinanceAccountingConfigUpdatesGet = {}));
var logsFinanceFolioGet;
(function (logsFinanceFolioGet) {
    logsFinanceFolioGet.EventTypesEnumValues = Object.freeze(['Created', 'ChargePosted', 'TransitoryChargePosted', 'AllowancePosted', 'PaymentPosted', 'ChargeMovedFromFolio', 'TransitoryChargeMovedFromFolio', 'PaymentMovedFromFolio', 'ChargeMovedToFolio', 'TransitoryChargeMovedToFolio', 'PaymentMovedToFolio', 'Closed', 'Reopened', 'Deleted', 'DebitorChanged', 'AllowanceMovedFromFolio', 'AllowanceMovedToFolio', 'RefundPosted', 'RefundMovedFromFolio', 'RefundMovedToFolio', 'InvoiceCreated', 'InvoiceCanceled', 'InvoicePaid', 'ChargesChanged', 'PaymentAdded', 'PaymentFailed', 'PaymentCanceled', 'RefundAdded', 'RefundFailed', 'InvoiceWrittenOff', 'DepositItemAdded', 'DepositItemChanged', 'DepositItemDeleted']);
})(logsFinanceFolioGet || (logsFinanceFolioGet = {}));
var logsFinanceNightAuditGet;
(function (logsFinanceNightAuditGet) {
    logsFinanceNightAuditGet.StatusesEnumValues = Object.freeze(['InProgress', 'Success', 'Failure']);
})(logsFinanceNightAuditGet || (logsFinanceNightAuditGet = {}));
var logsFinanceTransactionsExportGet;
(function (logsFinanceTransactionsExportGet) {
    logsFinanceTransactionsExportGet.TypesEnumValues = Object.freeze(['Raw', 'Aggregate', 'AggregatePairs']);
})(logsFinanceTransactionsExportGet || (logsFinanceTransactionsExportGet = {}));
class FinanceLogsService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    logsFinanceAccountingConfigUpdatesGet($params, observe = 'body', reportProgress = false) {
        const statuses = $params.statuses;
        const propertyIds = $params.propertyIds;
        const subjectIds = $params.subjectIds;
        const dateFilter = $params.dateFilter;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (statuses) {
            queryParameters = queryParameters.set('statuses', statuses.join(COLLECTION_FORMATS['csv']));
        }
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        if (subjectIds) {
            queryParameters = queryParameters.set('subjectIds', subjectIds.join(COLLECTION_FORMATS['csv']));
        }
        if (dateFilter) {
            queryParameters = queryParameters.set('dateFilter', dateFilter.join(COLLECTION_FORMATS['csv']));
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/logs/v0-nsfw/finance/accounting-config-updates`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    logsFinanceFolioGet($params, observe = 'body', reportProgress = false) {
        const folioIds = $params.folioIds;
        const eventTypes = $params.eventTypes;
        const clientIds = $params.clientIds;
        const propertyIds = $params.propertyIds;
        const subjectIds = $params.subjectIds;
        const dateFilter = $params.dateFilter;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (folioIds) {
            queryParameters = queryParameters.set('folioIds', folioIds.join(COLLECTION_FORMATS['csv']));
        }
        if (eventTypes) {
            queryParameters = queryParameters.set('eventTypes', eventTypes.join(COLLECTION_FORMATS['csv']));
        }
        if (clientIds) {
            queryParameters = queryParameters.set('clientIds', clientIds.join(COLLECTION_FORMATS['csv']));
        }
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        if (subjectIds) {
            queryParameters = queryParameters.set('subjectIds', subjectIds.join(COLLECTION_FORMATS['csv']));
        }
        if (dateFilter) {
            queryParameters = queryParameters.set('dateFilter', dateFilter.join(COLLECTION_FORMATS['csv']));
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/logs/v0-nsfw/finance/folio`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    logsFinanceNightAuditGet($params, observe = 'body', reportProgress = false) {
        const statuses = $params.statuses;
        const propertyIds = $params.propertyIds;
        const subjectIds = $params.subjectIds;
        const dateFilter = $params.dateFilter;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (statuses) {
            queryParameters = queryParameters.set('statuses', statuses.join(COLLECTION_FORMATS['csv']));
        }
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        if (subjectIds) {
            queryParameters = queryParameters.set('subjectIds', subjectIds.join(COLLECTION_FORMATS['csv']));
        }
        if (dateFilter) {
            queryParameters = queryParameters.set('dateFilter', dateFilter.join(COLLECTION_FORMATS['csv']));
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/logs/v0-nsfw/finance/night-audit`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    logsFinanceTransactionsExportGet($params, observe = 'body', reportProgress = false) {
        const types = $params.types;
        const propertyIds = $params.propertyIds;
        const subjectIds = $params.subjectIds;
        const dateFilter = $params.dateFilter;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (types) {
            queryParameters = queryParameters.set('types', types.join(COLLECTION_FORMATS['csv']));
        }
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        if (subjectIds) {
            queryParameters = queryParameters.set('subjectIds', subjectIds.join(COLLECTION_FORMATS['csv']));
        }
        if (dateFilter) {
            queryParameters = queryParameters.set('dateFilter', dateFilter.join(COLLECTION_FORMATS['csv']));
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/logs/v0-nsfw/finance/transactions-export`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function FinanceLogsService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || FinanceLogsService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: FinanceLogsService, factory: FinanceLogsService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(FinanceLogsService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

const APIS = [AuditLogsService, BookingLogsService, FinanceLogsService];

var AccountingConfigUpdateListModel;
(function (AccountingConfigUpdateListModel) {
    AccountingConfigUpdateListModel.$metaData = {
        logEntries: Object.freeze({
            isRequired: true,
            type: 'Array<AccountingConfigUpdateLogItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(AccountingConfigUpdateListModel || (AccountingConfigUpdateListModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var AccountingConfigUpdateLogItemModel;
(function (AccountingConfigUpdateLogItemModel) {
    AccountingConfigUpdateLogItemModel.StatusEnumValues = Object.freeze(['InProgress', 'Success', 'Failure']);
    AccountingConfigUpdateLogItemModel.FailureCodeEnumValues = Object.freeze(['NotSpecified', 'Other']);
})(AccountingConfigUpdateLogItemModel || (AccountingConfigUpdateLogItemModel = {}));
(function (AccountingConfigUpdateLogItemModel) {
    AccountingConfigUpdateLogItemModel.$metaData = {
        ended: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        status: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: AccountingConfigUpdateLogItemModel.StatusEnumValues,
            isPrimitiveType: true,
        }),
        failureCode: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: AccountingConfigUpdateLogItemModel.FailureCodeEnumValues,
            isPrimitiveType: true,
        }),
        failureReason: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        created: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        subjectId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(AccountingConfigUpdateLogItemModel || (AccountingConfigUpdateLogItemModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var AmountModel;
(function (AmountModel) {
    AmountModel.VatTypeEnumValues = Object.freeze(['Null', 'VeryReduced', 'Reduced', 'Normal', 'Without', 'Special', 'ReducedCovid19', 'NormalCovid19', 'Mixed']);
})(AmountModel || (AmountModel = {}));
(function (AmountModel) {
    AmountModel.$metaData = {
        grossAmount: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        netAmount: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        vatType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: AmountModel.VatTypeEnumValues,
            isPrimitiveType: true,
        }),
        vatPercent: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        currency: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(AmountModel || (AmountModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ExternalReferencesChangeModel;
(function (ExternalReferencesChangeModel) {
    ExternalReferencesChangeModel.$metaData = {
        globalDistributionSystemId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        onlineTravelAgencyId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        onlineBookingToolId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        channelManagerId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ExternalReferencesChangeModel || (ExternalReferencesChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MonetaryValueModel;
(function (MonetaryValueModel) {
    MonetaryValueModel.$metaData = {
        amount: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        currency: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(MonetaryValueModel || (MonetaryValueModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var FolioChangeLogItemModel;
(function (FolioChangeLogItemModel) {
    FolioChangeLogItemModel.EventTypeEnumValues = Object.freeze(['Created', 'ChargePosted', 'TransitoryChargePosted', 'AllowancePosted', 'PaymentPosted', 'ChargeMovedFromFolio', 'TransitoryChargeMovedFromFolio', 'PaymentMovedFromFolio', 'ChargeMovedToFolio', 'TransitoryChargeMovedToFolio', 'PaymentMovedToFolio', 'Closed', 'Reopened', 'Deleted', 'DebitorChanged', 'AllowanceMovedFromFolio', 'AllowanceMovedToFolio', 'RefundPosted', 'RefundMovedFromFolio', 'RefundMovedToFolio', 'InvoiceCreated', 'InvoiceCanceled', 'InvoicePaid', 'ChargesChanged', 'PaymentAdded', 'PaymentFailed', 'PaymentCanceled', 'RefundAdded', 'RefundFailed', 'InvoiceWrittenOff', 'DepositItemAdded', 'DepositItemChanged', 'DepositItemDeleted']);
})(FolioChangeLogItemModel || (FolioChangeLogItemModel = {}));
(function (FolioChangeLogItemModel) {
    FolioChangeLogItemModel.$metaData = {
        folioId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        eventType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: FolioChangeLogItemModel.EventTypeEnumValues,
            isPrimitiveType: true,
        }),
        relatedEntityId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        relatedEntityDescription: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        amount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        clientId: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        expectedDeliveryDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        serviceDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        created: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        subjectId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(FolioChangeLogItemModel || (FolioChangeLogItemModel = {}));

var FolioChangeLogListModel;
(function (FolioChangeLogListModel) {
    FolioChangeLogListModel.$metaData = {
        logEntries: Object.freeze({
            isRequired: true,
            type: 'Array<FolioChangeLogItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(FolioChangeLogListModel || (FolioChangeLogListModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var LogEntryItemModel;
(function (LogEntryItemModel) {
    LogEntryItemModel.ActionTypeEnumValues = Object.freeze(['Created', 'Updated', 'Deleted']);
})(LogEntryItemModel || (LogEntryItemModel = {}));
(function (LogEntryItemModel) {
    LogEntryItemModel.$metaData = {
        id: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        timestamp: Object.freeze({
            type: 'Date',
            isPrimitiveType: true,
        }),
        clientId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        subjectId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        actionType: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: LogEntryItemModel.ActionTypeEnumValues,
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        aggregateType: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        aggregateId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        entityType: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        entityId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        previousData: Object.freeze({
            type: '{ [key: string]: any; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        currentData: Object.freeze({
            type: '{ [key: string]: any; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
    };
})(LogEntryItemModel || (LogEntryItemModel = {}));

var LogEntryListModel;
(function (LogEntryListModel) {
    LogEntryListModel.$metaData = {
        logs: Object.freeze({
            isRequired: true,
            type: 'Array<LogEntryItemModel>',
            isListContainer: true,
        }),
        nextCursor: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        pageSize: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(LogEntryListModel || (LogEntryListModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MessageItemCollection;
(function (MessageItemCollection) {
    MessageItemCollection.$metaData = {
        messages: Object.freeze({
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
    };
})(MessageItemCollection || (MessageItemCollection = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var NightAuditLogItemModel;
(function (NightAuditLogItemModel) {
    NightAuditLogItemModel.StatusEnumValues = Object.freeze(['InProgress', 'Success', 'Failure']);
    NightAuditLogItemModel.FailureCodeEnumValues = Object.freeze(['None', 'ProcessNoShowsFailed', 'ProcessFoliosFailed', 'ProcessOccupiedUnitsFailed', 'Unknown']);
})(NightAuditLogItemModel || (NightAuditLogItemModel = {}));
(function (NightAuditLogItemModel) {
    NightAuditLogItemModel.$metaData = {
        ended: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        setReservationsToNoShow: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        status: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: NightAuditLogItemModel.StatusEnumValues,
            isPrimitiveType: true,
        }),
        failureCode: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: NightAuditLogItemModel.FailureCodeEnumValues,
            isPrimitiveType: true,
        }),
        failureReason: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        reservationIdsSetToNoShow: Object.freeze({
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        created: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        subjectId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(NightAuditLogItemModel || (NightAuditLogItemModel = {}));

var NightAuditLogListModel;
(function (NightAuditLogListModel) {
    NightAuditLogListModel.$metaData = {
        logEntries: Object.freeze({
            isRequired: true,
            type: 'Array<NightAuditLogItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(NightAuditLogListModel || (NightAuditLogListModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationCancellationFeeChangeModel;
(function (ReservationCancellationFeeChangeModel) {
    ReservationCancellationFeeChangeModel.$metaData = {
        dueDateTime: Object.freeze({
            type: 'Date',
            isPrimitiveType: true,
        }),
        fee: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
    };
})(ReservationCancellationFeeChangeModel || (ReservationCancellationFeeChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationPaymentAccountChangeModel;
(function (ReservationPaymentAccountChangeModel) {
    ReservationPaymentAccountChangeModel.$metaData = {
        accountNumber: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        accountHolder: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        expiryMonth: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        expiryYear: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        paymentMethod: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        payerEmail: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        isVirtual: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        isActive: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
    };
})(ReservationPaymentAccountChangeModel || (ReservationPaymentAccountChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationAddressChangeModel;
(function (ReservationAddressChangeModel) {
    ReservationAddressChangeModel.$metaData = {
        addressLine1: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        addressLine2: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        postalCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        city: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        regionCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        countryCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationAddressChangeModel || (ReservationAddressChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationCompanyChangeModel;
(function (ReservationCompanyChangeModel) {
    ReservationCompanyChangeModel.$metaData = {
        name: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        taxId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationCompanyChangeModel || (ReservationCompanyChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationVehicleRegistrationChangeModel;
(function (ReservationVehicleRegistrationChangeModel) {
    ReservationVehicleRegistrationChangeModel.$metaData = {
        number: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        countryCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationVehicleRegistrationChangeModel || (ReservationVehicleRegistrationChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationPersonChangeModel;
(function (ReservationPersonChangeModel) {
    ReservationPersonChangeModel.TitleEnumValues = Object.freeze(['Mr', 'Ms', 'Dr', 'Prof', 'Mrs', 'Other']);
    ReservationPersonChangeModel.GenderEnumValues = Object.freeze(['Female', 'Male', 'Other', 'Unknown']);
    ReservationPersonChangeModel.IdentificationTypeEnumValues = Object.freeze(['SocialInsuranceNumber', 'PassportNumber', 'IdNumber', 'DriverLicenseNumber', 'VisaNumber', 'ForeignerIdentityNumber', 'TaxIdentificationNumber', 'Other']);
    ReservationPersonChangeModel.RelationshipToPrimaryGuestEnumValues = Object.freeze(['Grandparent', 'Grandchild', 'GreatGrandparent', 'GreatGrandchild', 'Parent', 'Child', 'Sibling', 'ParentInLaw', 'ChildInLaw', 'SiblingInLaw', 'Spouse', 'UncleOrAunt', 'NephewOrNiece', 'Guardian', 'Other']);
})(ReservationPersonChangeModel || (ReservationPersonChangeModel = {}));
(function (ReservationPersonChangeModel) {
    ReservationPersonChangeModel.$metaData = {
        title: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationPersonChangeModel.TitleEnumValues,
            isPrimitiveType: true,
        }),
        gender: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationPersonChangeModel.GenderEnumValues,
            isPrimitiveType: true,
        }),
        firstName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        middleInitial: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        lastName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        secondLastName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        email: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        phone: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        address: Object.freeze({
            type: 'ReservationAddressChangeModel',
            metaData: ReservationAddressChangeModel.$metaData
        }),
        nationalityCountryCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationNumber: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationAdditionalNumber: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationIssueDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationExpiryDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationIssuePlace: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        identificationType: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationPersonChangeModel.IdentificationTypeEnumValues,
            isPrimitiveType: true,
        }),
        personalTaxId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        preferredLanguage: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthPlace: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthFirstName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        birthLastName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        motherFirstName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        motherLastName: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        borderCrossingPlace: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        borderCrossingDate: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        company: Object.freeze({
            type: 'ReservationCompanyChangeModel',
            metaData: ReservationCompanyChangeModel.$metaData
        }),
        relationshipToPrimaryGuest: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationPersonChangeModel.RelationshipToPrimaryGuestEnumValues,
            isPrimitiveType: true,
        }),
        vehicleRegistration: Object.freeze({
            type: 'ReservationVehicleRegistrationChangeModel',
            metaData: ReservationVehicleRegistrationChangeModel.$metaData
        }),
    };
})(ReservationPersonChangeModel || (ReservationPersonChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationAddedChangeModel;
(function (ReservationAddedChangeModel) {
    ReservationAddedChangeModel.StatusEnumValues = Object.freeze(['Confirmed', 'InHouse', 'CheckedOut', 'Canceled', 'NoShow']);
    ReservationAddedChangeModel.ChannelCodeEnumValues = Object.freeze(['Direct', 'BookingCom', 'Ibe', 'ChannelManager', 'Expedia', 'Homelike', 'Hrs', 'AltoVita', 'DesVu']);
    ReservationAddedChangeModel.GuaranteeTypeEnumValues = Object.freeze(['PM6Hold', 'CreditCard', 'Prepayment', 'Company', 'Ota']);
    ReservationAddedChangeModel.TravelPurposeEnumValues = Object.freeze(['Business', 'Leisure']);
})(ReservationAddedChangeModel || (ReservationAddedChangeModel = {}));
(function (ReservationAddedChangeModel) {
    ReservationAddedChangeModel.$metaData = {
        externalReferences: Object.freeze({
            type: 'ExternalReferencesChangeModel',
            metaData: ExternalReferencesChangeModel.$metaData
        }),
        isOpenForCharges: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        arrival: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        departure: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        status: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationAddedChangeModel.StatusEnumValues,
            isPrimitiveType: true,
        }),
        blockId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        totalGrossAmount: Object.freeze({
            isRequired: true,
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        adults: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        comment: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        guestComment: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        externalCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        channelCode: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationAddedChangeModel.ChannelCodeEnumValues,
            isPrimitiveType: true,
        }),
        source: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        primaryGuest: Object.freeze({
            type: 'ReservationPersonChangeModel',
            metaData: ReservationPersonChangeModel.$metaData
        }),
        childrenAges: Object.freeze({
            type: 'Array<number>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
        additionalGuests: Object.freeze({
            type: 'Array<ReservationPersonChangeModel>',
            isListContainer: true,
        }),
        paymentAccount: Object.freeze({
            type: 'ReservationPaymentAccountChangeModel',
            metaData: ReservationPaymentAccountChangeModel.$metaData
        }),
        timeSlices: Object.freeze({
            isRequired: true,
            type: 'Array<ReservationTimeSliceChangeModel>',
            isListContainer: true,
        }),
        extraServices: Object.freeze({
            type: 'Array<ReservationServiceChangeModel>',
            isListContainer: true,
        }),
        guaranteeType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationAddedChangeModel.GuaranteeTypeEnumValues,
            isPrimitiveType: true,
        }),
        cancellationFee: Object.freeze({
            isRequired: true,
            type: 'ReservationCancellationFeeChangeModel',
            metaData: ReservationCancellationFeeChangeModel.$metaData
        }),
        noShowFee: Object.freeze({
            isRequired: true,
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        travelPurpose: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationAddedChangeModel.TravelPurposeEnumValues,
            isPrimitiveType: true,
        }),
        prePaymentAmount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        validationMessages: Object.freeze({
            type: 'Array<ReservationValidationMessageChangeModel>',
            isListContainer: true,
        }),
        companyId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        hasCityTax: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        marketSegmentId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationAddedChangeModel || (ReservationAddedChangeModel = {}));

var ReservationChangeLogItemModel;
(function (ReservationChangeLogItemModel) {
    ReservationChangeLogItemModel.EventTypeEnumValues = Object.freeze(['Created', 'Amended', 'CheckedIn', 'CheckedOut', 'Canceled', 'SetToNoShow', 'CityTaxAdded', 'CityTaxRemoved', 'UnitAssigned', 'UnitUnassigned', 'PaymentAccountSet', 'PaymentAccountRemoved', 'InvoiceStatusChanged', 'Changed', 'CheckInReverted', 'UnitLocked', 'UnitUnlocked']);
})(ReservationChangeLogItemModel || (ReservationChangeLogItemModel = {}));
(function (ReservationChangeLogItemModel) {
    ReservationChangeLogItemModel.$metaData = {
        reservationId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        eventType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationChangeLogItemModel.EventTypeEnumValues,
            isPrimitiveType: true,
        }),
        changes: Object.freeze({
            type: 'Array<ReservationChangeModel>',
            isListContainer: true,
        }),
        clientId: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        created: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        subjectId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationChangeLogItemModel || (ReservationChangeLogItemModel = {}));

var ReservationChangeLogListModel;
(function (ReservationChangeLogListModel) {
    ReservationChangeLogListModel.$metaData = {
        logEntries: Object.freeze({
            isRequired: true,
            type: 'Array<ReservationChangeLogItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(ReservationChangeLogListModel || (ReservationChangeLogListModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationChangedChangeModel;
(function (ReservationChangedChangeModel) {
    ReservationChangedChangeModel.GuaranteeTypeEnumValues = Object.freeze(['PM6Hold', 'CreditCard', 'Prepayment', 'Company', 'Ota']);
    ReservationChangedChangeModel.TravelPurposeEnumValues = Object.freeze(['Business', 'Leisure']);
})(ReservationChangedChangeModel || (ReservationChangedChangeModel = {}));
(function (ReservationChangedChangeModel) {
    ReservationChangedChangeModel.$metaData = {
        isOpenForCharges: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        isPreCheckedIn: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        externalReferences: Object.freeze({
            type: 'ExternalReferencesChangeModel',
            metaData: ExternalReferencesChangeModel.$metaData
        }),
        arrival: Object.freeze({
            type: 'Date',
            isPrimitiveType: true,
        }),
        departure: Object.freeze({
            type: 'Date',
            isPrimitiveType: true,
        }),
        adults: Object.freeze({
            type: 'number',
            isPrimitiveType: true,
        }),
        childrenAges: Object.freeze({
            type: 'Array<number>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
        comment: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        guestComment: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        totalGrossAmount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        primaryGuest: Object.freeze({
            type: 'ReservationPersonChangeModel',
            metaData: ReservationPersonChangeModel.$metaData
        }),
        paymentAccount: Object.freeze({
            type: 'ReservationPaymentAccountChangeModel',
            metaData: ReservationPaymentAccountChangeModel.$metaData
        }),
        guaranteeType: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationChangedChangeModel.GuaranteeTypeEnumValues,
            isPrimitiveType: true,
        }),
        travelPurpose: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationChangedChangeModel.TravelPurposeEnumValues,
            isPrimitiveType: true,
        }),
        companyId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        noShowFee: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        cancellationFee: Object.freeze({
            type: 'ReservationCancellationFeeChangeModel',
            metaData: ReservationCancellationFeeChangeModel.$metaData
        }),
        commissionAmount: Object.freeze({
            type: 'MonetaryValueModel',
            metaData: MonetaryValueModel.$metaData
        }),
        hasCityTax: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        marketSegmentId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationChangedChangeModel || (ReservationChangedChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationServiceChangeModel;
(function (ReservationServiceChangeModel) {
    ReservationServiceChangeModel.$metaData = {
        serviceId: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        count: Object.freeze({
            type: 'number',
            isPrimitiveType: true,
        }),
        amount: Object.freeze({
            type: 'AmountModel',
            metaData: AmountModel.$metaData
        }),
        totalAmount: Object.freeze({
            type: 'AmountModel',
            metaData: AmountModel.$metaData
        }),
        serviceDate: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationServiceChangeModel || (ReservationServiceChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationTimeSliceChangeModel;
(function (ReservationTimeSliceChangeModel) {
    ReservationTimeSliceChangeModel.$metaData = {
        ratePlanId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        from: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        to: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        unitId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        amount: Object.freeze({
            type: 'AmountModel',
            metaData: AmountModel.$metaData
        }),
    };
})(ReservationTimeSliceChangeModel || (ReservationTimeSliceChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationValidationMessageChangeModel;
(function (ReservationValidationMessageChangeModel) {
    ReservationValidationMessageChangeModel.CategoryEnumValues = Object.freeze(['OfferNotAvailable', 'AutoUnitAssignment']);
    ReservationValidationMessageChangeModel.CodeEnumValues = Object.freeze(['UnitGroupFullyBooked', 'UnitGroupCapacityExceeded', 'RatePlanRestrictionsViolated', 'RatePlanSurchargesNotSet', 'RateRestrictionsViolated', 'RatePlanChannelNotSet', 'RatesNotSet', 'BlockFullyBooked', 'UnitMoved', 'IncludedServicesAmountExceededRateAmount', 'RatePlanCompanyRestrictionsViolated', 'ServiceFullyBooked']);
})(ReservationValidationMessageChangeModel || (ReservationValidationMessageChangeModel = {}));
(function (ReservationValidationMessageChangeModel) {
    ReservationValidationMessageChangeModel.$metaData = {
        category: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationValidationMessageChangeModel.CategoryEnumValues,
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationValidationMessageChangeModel.CodeEnumValues,
            isPrimitiveType: true,
        }),
        message: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ReservationValidationMessageChangeModel || (ReservationValidationMessageChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReservationChangeModel;
(function (ReservationChangeModel) {
    ReservationChangeModel.ChangeTypeEnumValues = Object.freeze(['ReservationAdded', 'ReservationChanged', 'AdditionalGuestAdded', 'AdditionalGuestRemoved', 'AdditionalGuestChanged', 'TimeSliceAdded', 'TimeSliceRemoved', 'TimeSliceChanged', 'ExtraServiceAdded', 'ExtraServiceRemoved', 'ExtraServiceChanged', 'ValidationMessageAdded', 'ValidationMessageRemoved']);
})(ReservationChangeModel || (ReservationChangeModel = {}));
(function (ReservationChangeModel) {
    ReservationChangeModel.$metaData = {
        changeType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ReservationChangeModel.ChangeTypeEnumValues,
            isPrimitiveType: true,
        }),
        reservationAddedValue: Object.freeze({
            type: 'ReservationAddedChangeModel',
            metaData: ReservationAddedChangeModel.$metaData
        }),
        newReservationChangedValue: Object.freeze({
            type: 'ReservationChangedChangeModel',
            metaData: ReservationChangedChangeModel.$metaData
        }),
        oldReservationChangedValue: Object.freeze({
            type: 'ReservationChangedChangeModel',
            metaData: ReservationChangedChangeModel.$metaData
        }),
        newAdditionalGuestValue: Object.freeze({
            type: 'ReservationPersonChangeModel',
            metaData: ReservationPersonChangeModel.$metaData
        }),
        oldAdditionalGuestValue: Object.freeze({
            type: 'ReservationPersonChangeModel',
            metaData: ReservationPersonChangeModel.$metaData
        }),
        newTimeSliceValue: Object.freeze({
            type: 'ReservationTimeSliceChangeModel',
            metaData: ReservationTimeSliceChangeModel.$metaData
        }),
        oldTimeSliceValue: Object.freeze({
            type: 'ReservationTimeSliceChangeModel',
            metaData: ReservationTimeSliceChangeModel.$metaData
        }),
        newExtraServiceValue: Object.freeze({
            type: 'ReservationServiceChangeModel',
            metaData: ReservationServiceChangeModel.$metaData
        }),
        oldExtraServiceValue: Object.freeze({
            type: 'ReservationServiceChangeModel',
            metaData: ReservationServiceChangeModel.$metaData
        }),
        newValidationMessageValue: Object.freeze({
            type: 'ReservationValidationMessageChangeModel',
            metaData: ReservationValidationMessageChangeModel.$metaData
        }),
        oldValidationMessageValue: Object.freeze({
            type: 'ReservationValidationMessageChangeModel',
            metaData: ReservationValidationMessageChangeModel.$metaData
        }),
    };
})(ReservationChangeModel || (ReservationChangeModel = {}));

/**
 * apaleo logs API - not safe for work
 * Continuously evolving version - use at your own risk! Different logs: night audit, transactions export, folio change log
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var TransactionsExportLogItemModel;
(function (TransactionsExportLogItemModel) {
    TransactionsExportLogItemModel.TypeEnumValues = Object.freeze(['Raw', 'Aggregate', 'AggregatePairs']);
})(TransactionsExportLogItemModel || (TransactionsExportLogItemModel = {}));
(function (TransactionsExportLogItemModel) {
    TransactionsExportLogItemModel.$metaData = {
        periodStart: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        periodEnd: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: TransactionsExportLogItemModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        created: Object.freeze({
            isRequired: true,
            type: 'Date',
            isPrimitiveType: true,
        }),
        subjectId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(TransactionsExportLogItemModel || (TransactionsExportLogItemModel = {}));

var TransactionsExportLogListModel;
(function (TransactionsExportLogListModel) {
    TransactionsExportLogListModel.$metaData = {
        logEntries: Object.freeze({
            isRequired: true,
            type: 'Array<TransactionsExportLogItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(TransactionsExportLogListModel || (TransactionsExportLogListModel = {}));

class ApiModule {
    static forRoot(configurationFactory) {
        return {
            ngModule: ApiModule,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    }
    constructor(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    static { this.ɵfac = function ApiModule_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || ApiModule)(i0.ɵɵinject(ApiModule, 12), i0.ɵɵinject(i1.HttpClient, 8)); }; }
    static { this.ɵmod = /*@__PURE__*/ i0.ɵɵdefineNgModule({ type: ApiModule }); }
    static { this.ɵinj = /*@__PURE__*/ i0.ɵɵdefineInjector({ providers: [
            AuditLogsService,
            BookingLogsService,
            FinanceLogsService
        ] }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ApiModule, [{
        type: NgModule,
        args: [{
                imports: [],
                declarations: [],
                exports: [],
                providers: [
                    AuditLogsService,
                    BookingLogsService,
                    FinanceLogsService
                ]
            }]
    }], () => [{ type: ApiModule, decorators: [{
                type: Optional
            }, {
                type: SkipSelf
            }] }, { type: i1.HttpClient, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * Generated bundle index. Do not edit.
 */

export { APIS, AccountingConfigUpdateListModel, AccountingConfigUpdateLogItemModel, AmountModel, ApiModule, AuditLogsService, BASE_PATH, BookingLogsService, COLLECTION_FORMATS, Configuration, ExternalReferencesChangeModel, FinanceLogsService, FolioChangeLogItemModel, FolioChangeLogListModel, LogEntryItemModel, LogEntryListModel, MessageItemCollection, MonetaryValueModel, NightAuditLogItemModel, NightAuditLogListModel, ReservationAddedChangeModel, ReservationAddressChangeModel, ReservationCancellationFeeChangeModel, ReservationChangeLogItemModel, ReservationChangeLogListModel, ReservationChangeModel, ReservationChangedChangeModel, ReservationCompanyChangeModel, ReservationPaymentAccountChangeModel, ReservationPersonChangeModel, ReservationServiceChangeModel, ReservationTimeSliceChangeModel, ReservationValidationMessageChangeModel, ReservationVehicleRegistrationChangeModel, TransactionsExportLogItemModel, TransactionsExportLogListModel, logsAuditLogsGet, logsBookingReservationGet, logsFinanceAccountingConfigUpdatesGet, logsFinanceFolioGet, logsFinanceNightAuditGet, logsFinanceTransactionsExportGet };
//# sourceMappingURL=apaleo-angular-api-proxy-logs.mjs.map
